[−][src]Crate dt_analysis
A currently heavily unstable crate containing algorithms relating to data analysis for anomaly detection. The API will experience numerous breaking changes for the time being until the API is finalized (v1.0)
Modules
| dim_reduction | Dimensionality reduction techniques. |
| dist | Distance algorithms between two lists of floats. |
| keogh | Implements the brute force and HOT SAX algorithms as specified by Keogh's paper, found here. |
| util | Miscellaneous utility functions. |